@@ -14,7 +14,7 @@ from django.contrib.auth.decorators import permission_required
 from noc.lib.render import render,render_plain_text,render_success,render_failure,render_json
 from noc.lib.fileutils import temporary_file
 from noc.fm.models import Event,EventData,EventClassificationRule,EventClassificationRE,EventPriority, EventClass,\
-    MIB, MIBRequiredException, EventCategory, EVENT_STATUS_CHOICES, EventPostProcessingRule, EventPostProcessingRE
+    MIB, MIBRequiredException, EventCategory, EVENT_STATUS_CHOICES, EventPostProcessingRule, EventPostProcessingRE, EventCorrelationRule
 from noc.sa.models import ManagedObject
 from django.http import HttpResponseRedirect,HttpResponseForbidden, HttpResponse
 from django.core.paginator import Paginator, InvalidPage, EmptyPage
@@ -102,7 +102,13 @@ class EventSearchForm(forms.Form):
 ##
 @permission_required("fm.change_event")
 def index(request):
-    form=EventSearchForm(initial={"status":"A"})
+    initial={"status":"A"}
+    try:
+        initial["event_priority"]=EventPriority.objects.get(name="WARNING").id
+    except EventPriority.DoesNotExist:
+        pass
+    print initial
+    form=EventSearchForm(initial=initial)
     return render(request,"fm/index.html",{"form":form})
 ##
 ## Dynamically generated CSS for event list priorities
@@ -222,6 +228,14 @@ def py_event_classification_rule(request,rule_id):
     rule=get_object_or_404(EventClassificationRule,id=int(rule_id))
     return render_plain_text(rule.python_code)
 ##
+## Convert event correlation rule to python code
+##
+@permission_required("fm.add_eventcorrelationrule")
+def py_event_correlation_rule(request,rule_id):
+    rule=get_object_or_404(EventCorrelationRule,id=int(rule_id))
+    return render_plain_text(rule.python_code)
+
+##
 ## MIB Upload
 ##
 class MIBUploadForm(forms.Form):
@@ -249,3 +263,29 @@ def reload_classifier_config(request):
     referer=request.META.get("HTTP_REFERER","/admin/fm/eventclassificationrule/")
     refresh_config("noc-classifier")
     return HttpResponseRedirect(referer)
+##
+## Reload noc-correlator config
+##
+@permission_required("fm.add_eventcorrelationrule")
+def reload_correlator_config(request):
+    referer=request.META.get("HTTP_REFERER","/admin/fm/eventcorrelationrule/")
+    refresh_config("noc-correlator")
+    return HttpResponseRedirect(referer)
+##
+## Active problems summary
+##
+@permission_required("fm.change_event")
+def active_problems_summary(request):
+    from django.db import connection
+    cursor=connection.cursor()
+    cursor.execute("""SELECT o.name AS object_name,ec.name AS class_name,ep.name AS priority_name,COUNT(*) AS count
+    FROM fm_event e JOIN sa_managedobject o ON (e.managed_object_id=o.id)
+        JOIN fm_eventclass ec ON (ec.id=e.event_class_id)
+        JOIN fm_eventpriority ep ON (e.event_priority_id=ep.id)
+    WHERE
+        e.status='A' AND ep.priority>1000
+    GROUP BY 1,2,3
+    ORDER BY 1,3,2,4 DESC
+    """)
+    data=cursor.fetchall()
+    return render(request,"fm/active_problems_summary.html",{"data":data})
