@@ -7,6 +7,7 @@
 ##----------------------------------------------------------------------
 from django.db import models
 from lib.ip import normalize_prefix
+import types
 ##
 ## CIDRField maps to PostgreSQL CIDR
 ##
@@ -30,3 +31,19 @@ class CIDRField(models.Field):
 class BinaryField(models.Field):
     def db_type(self):
         return "BYTEA"
+##
+## Text Array field maps to PostgreSQL TEXT[] type
+##
+class TextArrayField(models.Field):
+    __metaclass__ = models.SubfieldBase
+    
+    def db_type(self):
+        return "TEXT[]"
+
+    def to_python(self,value):
+        def to_unicode(s):
+            if type(s)==types.UnicodeType:
+                return s
+            else:
+                return unicode(s,"utf-8")
+        return [to_unicode(x) for x in value]
