@@ -24,7 +24,20 @@ class MIMETypeAdmin(admin.ModelAdmin):
     list_display=["extension","mime_type"]
     search_fields=["extension","mime_type"]
 ##
+class RefBookFieldAdmin(admin.TabularInline):
+    extra=3
+    model=RefBookField
+##
+## Admin for Ref Books
+##
+class RefBookAdmin(admin.ModelAdmin):
+    list_display=["name","is_builtin","is_enabled"]
+    search_fields=["name"]
+    list_filter=["is_enabled","is_builtin"]
+    inlines=[RefBookFieldAdmin]
+##
 ## Register administrative interfaces
 ##
 admin.site.register(Language, LanguageAdmin)
 admin.site.register(MIMEType, MIMETypeAdmin)
+admin.site.register(RefBook, RefBookAdmin)
