@@ -9,8 +9,8 @@ import noc.sa.script
 from noc.sa.interfaces import IGetVersion
 import re
 
-rx_sys=re.compile(r"System description:\s+.*?(?P<platform>ES.+?)$",re.MULTILINE|re.DOTALL)
-rx_ver=re.compile(r"Operation code version\s+(?P<version>\S+)",re.MULTILINE|re.DOTALL)
+rx_sys=re.compile(r"System description:\s+.*?(?P<platform>ES.+?)$",re.MULTILINE|re.DOTALL|re.IGNORECASE)
+rx_ver=re.compile(r"Operation code version\s+(?P<version>\S+)",re.MULTILINE|re.DOTALL|re.IGNORECASE)
 
 class Script(noc.sa.script.Script):
     name="EdgeCore.ES35xx.get_version"
