@@ -16,6 +16,7 @@ class ProfileRegistry(Registry):
     subdir="profiles"
     classname="Profile"
     apps=["noc.sa"]
+    exclude=["highlight"]
 profile_registry=ProfileRegistry()
 
 ##
@@ -93,9 +94,9 @@ class Profile(object):
     ## Looking glass hilighting support
     ##
     
-    # match.group(1) contains AS list
+    # match.group(1) contains AS list <!> Deprecated
     pattern_lg_as_path_list=None
-    # match.group(1) containts Best Path
+    # match.group(1) containts Best Path <!> Deprecated
     pattern_lg_best_path=None
     # Does the equipment supports bitlength netmasks
     # or netmask should be converted to traditional formats
@@ -103,7 +104,8 @@ class Profile(object):
     
     #
     # AS Path hilighting
-    #
+    # Deprecated <!>
+    # 
     def lg_as_path(self,m):
         def whois_formatter(q):
             return "<A HREF='http://www.db.ripe.net/whois?AS%s'>%s</A>"%(q,q)
@@ -171,11 +173,29 @@ class Profile(object):
                 cfg=rx.sub("",cfg)
         return unicode(cfg,"utf8","ignore").encode("utf8") # Prevent serialization errors
     #
-    # SNMP support
-    #
-    
-    # OID of "config changed trap".
-    oid_trap_config_changed=None
-    # Regular expression to parse "config changed" syslog message
-    syslog_config_changed=None
+    # Highligh config
+    # Try to include profile's highlight module and use its ConfigLexer
+    # Returns escaped HTML
     #
+    def highlight_config(self,cfg):
+        from django.utils.html import escape
+        # Check for pygments available
+        try:
+            from pygments import highlight
+        except ImportError:
+            # No pygments, no highlighting. Return escaped HTML
+            return "<pre><!--no pygments-->%s</pre>"%escape(cfg).replace("\n","<br/>")
+        # Check for lexer available
+        from pygments.lexers import TextLexer
+        from noc.lib.highlight import NOCHtmlFormatter
+        try:
+            h_mod="noc.sa.profiles.%s.highlight"%self.name
+            m=__import__(h_mod,{},{},"ConfigLexer")
+            try:
+                lexer=m.ConfigLexer
+            except AttributeError:
+                lexer=TextLexer # Fallback to TextLexer
+        except ImportError:
+            lexer=TextLexer
+        # Return highlighted text
+        return highlight(cfg, lexer(), NOCHtmlFormatter())
